==> zio-aws-ec2_2.12-5.17.103.1-sources.jar: zio/aws/ec2/model/CpuOptions.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CpuOptions(
    coreCount: Option[Integer] = None,
    threadsPerCore: Option[Integer] = None
) {
  def buildAwsValue(): software.amazon.awssdk.services.ec2.model.CpuOptions = {
    import CpuOptions.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.CpuOptions
      .builder()
      .optionallyWith(
        coreCount.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.coreCount)
      .optionallyWith(
        threadsPerCore.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.threadsPerCore)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.CpuOptions.ReadOnly =
    zio.aws.ec2.model.CpuOptions.wrap(buildAwsValue())
}
object CpuOptions {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.ec2.model.CpuOptions] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.CpuOptions = zio.aws.ec2.model.CpuOptions(
      coreCount.map(value => value),
      threadsPerCore.map(value => value)
    )
    def coreCount: Option[Integer]
    def threadsPerCore: Option[Integer]
    def getCoreCount: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("coreCount", coreCount)
    def getThreadsPerCore: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("threadsPerCore", threadsPerCore)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.CpuOptions
  ) extends zio.aws.ec2.model.CpuOptions.ReadOnly {
    override val coreCount: Option[Integer] = scala
      .Option(impl.coreCount())
      .map(value => zio.aws.ec2.model.primitives.Integer(value))
    override val threadsPerCore: Option[Integer] = scala
      .Option(impl.threadsPerCore())
      .map(value => zio.aws.ec2.model.primitives.Integer(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.CpuOptions
  ): zio.aws.ec2.model.CpuOptions.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.155.1-sources.jar: zio/aws/ec2/model/CpuOptions.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CpuOptions(
    coreCount: Option[Integer] = None,
    threadsPerCore: Option[Integer] = None
) {
  def buildAwsValue(): software.amazon.awssdk.services.ec2.model.CpuOptions = {
    import CpuOptions.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.CpuOptions
      .builder()
      .optionallyWith(coreCount.map(value => value: java.lang.Integer))(
        _.coreCount
      )
      .optionallyWith(threadsPerCore.map(value => value: java.lang.Integer))(
        _.threadsPerCore
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.CpuOptions.ReadOnly =
    zio.aws.ec2.model.CpuOptions.wrap(buildAwsValue())
}
object CpuOptions {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.ec2.model.CpuOptions] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.CpuOptions = zio.aws.ec2.model.CpuOptions(
      coreCount.map(value => value),
      threadsPerCore.map(value => value)
    )
    def coreCount: Option[Integer]
    def threadsPerCore: Option[Integer]
    def getCoreCount: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("coreCount", coreCount)
    def getThreadsPerCore: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("threadsPerCore", threadsPerCore)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.CpuOptions
  ) extends zio.aws.ec2.model.CpuOptions.ReadOnly {
    override val coreCount: Option[Integer] =
      scala.Option(impl.coreCount()).map(value => value: Integer)
    override val threadsPerCore: Option[Integer] =
      scala.Option(impl.threadsPerCore()).map(value => value: Integer)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.CpuOptions
  ): zio.aws.ec2.model.CpuOptions.ReadOnly = new Wrapper(impl)
}
